@@ -214,6 +214,17 @@ class Seti():
         encode_data = self.sign_data(data_create_dispersion)
         return ResponseCreateTransaction(self.send_request(data_create_dispersion,encode_data,CREATE_DISPERSION_URL))
     
+    def create_dispersion_associated(self,value:int,toSecret:str):
+        self.is_error =False
+        self.validate_value(value)
+        data_create_dispersion = {
+            "toSecret": toSecret,
+            "value": value,
+        }
+        CREATE_DISPERSION_URL = "dispersion-money-associated"
+        encode_data = self.sign_data(data_create_dispersion)
+        return ResponseCreateTransaction(self.send_request(data_create_dispersion,encode_data,CREATE_DISPERSION_URL))
+    
     
     # Read
     def read_payment(self,payment_id:str):
