@@ -124,7 +124,7 @@ class Transaction:
         self.from_wallet_id=data["fromWalletId"]
         self.timestamp=data["timestamp"]
         self.payment_id=data["paymentId"]
-        self.transaction_iype=data["transactionType"]
+        self.transaction_type=data["transactionType"]
         if "toBusinessId" in data:
             self.to_business_id=data["toBusinessId"]
             self.from_nusiness_id=data["fromBusinessId"]
